@@ -491,6 +491,14 @@ class RiakBucket(object):
         """
         return self._client.transport.get_bucket_props(self)
 
+    def reset_properties(self):
+        """
+        Reset all bucket properties to defaults.
+
+        :rtype: None - deferred
+        """
+        return self._client.transport.reset_bucket_props(self)
+
     def get_keys(self):
         """
         Return all keys within the bucket.
@@ -558,7 +566,7 @@ class RiakBucket(object):
         """
         Queries a secondary index over objects in this bucket, returning keys.
         """
-        return self._client._transport.get_index(self._name, index, startkey, endkey)
+        return self._client.transport.get_index(self._name, index, startkey, endkey)
 
     def list_keys(self):
         """ Same as get_keys - for txRiak compat """
